Structs
- Cache
Stats - A snapshot of cache hit, miss, insertion, and eviction counters.
- Memory
Cache - A bounded in-process LRU cache with per-entry expiry and cache statistics.
- Read
Through Cache - A bounded cache that coalesces concurrent misses for the same key.
- TtlCache
- A thread-safe in-memory cache that expires entries on access.