Module discov

Module discov 

Structs

DiscoveredEndpoint
Transport-neutral metadata attached to a discovered service endpoint.
DiscoveryReconnectBackoff
Capped exponential delay used by reconnecting discovery backends.
ServiceLease
A published endpoint. Dropping it withdraws the endpoint when its final lease is released.
ServiceRegistry
A local service registry with reference-counted endpoint leases and change subscriptions.
ServiceSubscription
Receives dynamic endpoint changes for one service.

Enums

DiscoveryError
Errors produced while publishing or subscribing to services.
ServiceEvent
A service endpoint change.

Traits

EndpointSubscription
A live, complete snapshot of the endpoints for one logical service.

Type Aliases

EndpointChangeFuture
Future returned while waiting for a discovery snapshot to change.