Skip to main contentModule log
Source - LogConfig
- Standalone structured logger configuration.
- LogContext
- Fields shared by logs emitted while handling one request or operation.
- LogField
- One structured key/value pair.
- LogSampler
- A cheap deterministic sampler that keeps an initial burst and then every Nth event.
- Logger
- Cloneable, process-wide structured logger.
- LogEncoding
- Encoding used for each emitted log record.
- LogError
- LogLevel
- Severity threshold and event level for structured logs.
- LogTarget
- Destination for log records.
- RotationPolicy
- File rollover strategy.
- Sensitive
- Opt-in desensitization for values containing secrets or personal information.