pub struct RunningQueue { /* private fields */ }Expand description
Control and supervision handle for a running queue.
Implementations
Sourceimpl RunningQueue
impl RunningQueue
pub fn subscribe(&self) -> Receiver<QueueEvent>
pub fn is_paused(&self) -> bool
pub fn pause(&self)
pub fn resume(&self)
Sourcepub async fn shutdown(self) -> Result<(), QueueRuntimeError>
pub async fn shutdown(self) -> Result<(), QueueRuntimeError>
Requests shutdown and waits for all workers to stop within the configured deadline.
Sourcepub async fn wait(self) -> Result<(), QueueRuntimeError>
pub async fn wait(self) -> Result<(), QueueRuntimeError>
Waits for workers to exit because all producers were dropped.
A panic in any worker is surfaced and causes the remaining workers to be stopped.