Module service

Module service 

Structs

RunningServices
ServiceGroup
Starts and supervises a set of long-running asynchronous services.
Shutdown
A cancellation signal passed to every service in a ServiceGroup.
ShutdownHandle
A clonable handle that requests graceful shutdown of a running service group.

Enums

ServiceGroupError
ShutdownSignal
A process signal that conventionally requests graceful shutdown.

Functions

wait_for_shutdown_signal
Waits for SIGINT or SIGTERM without terminating the process immediately.