Module stores_redis

Module stores_redis 

Redis data structures, locks, streams, subscriptions, and model caching.

use rust_zero_core::{RedisStore, RedisStoreConfig};
let redis = RedisStore::new(RedisStoreConfig::new("redis://127.0.0.1/"))?;
redis.ping().await?;

Structs

RedisJsonCache
JSON cache-aside access backed by Redis with per-key miss coalescing.
RedisLock
RedisModelCache
Redis-backed positive and not-found model caching with per-process miss coalescing.
RedisModelCacheConfig
Expiry and not-found policy for a Redis-backed model cache.
RedisStore
RedisStoreConfig
RedisStoreMetrics
Cardinality-bounded Redis command metrics installed on RedisStore.
RedisSubscription
Receiver for a reconnecting Redis channel or pattern subscription.
RedisSubscriptionConfig
Delivery and reconnect policy for a Redis Pub/Sub subscription.
RedisSubscriptionMessage
One binary-safe message received from a channel or pattern subscription.

Enums

RedisCacheError
RedisModelCacheError
RedisStoreError
RedisSubscriptionEvent
Observable subscription state and delivery events.
RedisTtl