Module cache

Module cache 

Structs

CacheStats
A snapshot of cache hit, miss, insertion, and eviction counters.
MemoryCache
A bounded in-process LRU cache with per-entry expiry and cache statistics.
ReadThroughCache
A bounded cache that coalesces concurrent misses for the same key.
TtlCache
A thread-safe in-memory cache that expires entries on access.