Kubernetes EndpointSlice service discovery.
use rust_zero_core::{KubernetesDiscovery, KubernetesDiscoveryConfig};
let discovery = KubernetesDiscovery::infer(
KubernetesDiscoveryConfig::new("production").with_port_name("grpc"),
).await?;
let subscription = discovery.subscribe("users").await?;
println!("{:?}", subscription.endpoints());Structs
- Kubernetes
Discovery - A Kubernetes client that discovers ready addresses from EndpointSlices.
- Kubernetes
Discovery Config - Namespace, port, and URI settings for Kubernetes EndpointSlice discovery.
- Kubernetes
Service Subscription - A live, complete endpoint snapshot for one Kubernetes Service.