Redis data structures, locks, streams, subscriptions, and model caching.
use rust_zero_core::{RedisStore, RedisStoreConfig};
let redis = RedisStore::new(RedisStoreConfig::new("redis://127.0.0.1/"))?;
redis.ping().await?;Structs
- Redis
Json Cache - JSON cache-aside access backed by Redis with per-key miss coalescing.
- Redis
Lock - Redis
Model Cache - Redis-backed positive and not-found model caching with per-process miss coalescing.
- Redis
Model Cache Config - Expiry and not-found policy for a Redis-backed model cache.
- Redis
Store - Redis
Store Config - Redis
Store Metrics - Cardinality-bounded Redis command metrics installed on
RedisStore. - Redis
Subscription - Receiver for a reconnecting Redis channel or pattern subscription.
- Redis
Subscription Config - Delivery and reconnect policy for a Redis Pub/Sub subscription.
- Redis
Subscription Message - One binary-safe message received from a channel or pattern subscription.
Enums
- Redis
Cache Error - Redis
Model Cache Error - Redis
Store Error - Redis
Subscription Event - Observable subscription state and delivery events.
- Redis
Ttl